Changelog
=========

0.1
---
#. Introduce dependency on `jmbo-foundry`.
#. Simplify templates and remove excessive views.

0.0.5
-----
#. Modify query so non-public tracks for a chart are not returned.

0.0.4 (2011-08-22)
------------------
#. Initial release.

